@@ -1,3 +1,4 @@
+from http.server import BaseHTTPRequestHandler, HTTPServer
 import threading
 import time
 import unittest
@@ -15,12 +16,6 @@ from prometheus_client.exposition import (
     passthrough_redirect_handler,
 )
 
-try:
-    from BaseHTTPServer import BaseHTTPRequestHandler, HTTPServer
-except ImportError:
-    # Python 3
-    from http.server import BaseHTTPRequestHandler, HTTPServer
-
 
 class TestGenerateText(unittest.TestCase):
     def setUp(self):
